@@ -8,6 +8,7 @@
 # References:   1) PLUS - http://ns.useplus.org/
 #               2) PRISM - http://www.prismstandard.org/
 #               3) http://www.portfoliofaq.com/pfaq/v7mappings.htm
+#               4) http://www.iptc.org/IPTC4XMP/
 #               5) http://creativecommons.org/technology/xmp
 #                  --> changed to http://wiki.creativecommons.org/Companion_File_metadata_specification (2007/12/21)
 #               6) http://www.optimasc.com/products/fileid/xmp-extensions.pdf
@@ -22,6 +23,8 @@ use strict;
 use Image::ExifTool qw(:Utils);
 use Image::ExifTool::XMP;
 
+#------------------------------------------------------------------------------
+
 # xmpDM structure definitions
 my %sCuePointParam = (
     STRUCT_NAME => 'CuePointParam',
@@ -69,7 +72,7 @@ my %sTimecode = (
         },
     },
     timeValue   => { },
-    value       => { Writable => 'integer' },
+    value       => { Writable => 'integer', Notes => 'only in XMP 2008 spec; an error?' },
 );
 
 # XMP Dynamic Media namespace properties (xmpDM)
@@ -276,7 +279,7 @@ my %sTimecode = (
             'CCIR-709' => 'CCIR-709',
         },
     },
-    videoCompressor     => { },
+    videoCompressor => { },
     videoFieldOrder => {
         PrintConv => {
             Upper => 'Upper',
@@ -284,9 +287,9 @@ my %sTimecode = (
             Progressive => 'Progressive',
         },
     },
-    videoFrameRate      => { Writable => 'real' },
-    videoFrameSize      => { Struct => \%sDimensions },
-    videoModDate        => { Groups => { 2 => 'Time' }, %dateTimeInfo },
+    videoFrameRate  => { Writable => 'real' },
+    videoFrameSize  => { Struct => \%sDimensions },
+    videoModDate    => { Groups => { 2 => 'Time' }, %dateTimeInfo },
     videoPixelAspectRatio => { Writable => 'rational' },
     videoPixelDepth => {
         PrintConv => {
@@ -300,10 +303,378 @@ my %sTimecode = (
     },
 );
 
+#------------------------------------------------------------------------------
+# IPTC Extensions version 1.3 (+ proposed video extensions)
+
+# IPTC Extension 1.0 structures
+my %sLocationDetails = (
+    STRUCT_NAME => 'LocationDetails',
+    NAMESPACE   => 'Iptc4xmpExt',
+    GROUPS      => { 2 => 'Location' },
+    Identifier  => { List => 'Bag', Namespace => 'xmp' },
+    City        => { },
+    CountryCode => { },
+    CountryName => { },
+    ProvinceState => { },
+    Sublocation => { },
+    WorldRegion => { },
+    LocationId  => { List => 'Bag' },
+    LocationName => { Writable => 'lang-alt' },
+    GPSLatitude  => { Namespace => 'exif', %latConv },
+    GPSLongitude => { Namespace => 'exif', %longConv },
+    GPSAltitude => {
+        Namespace => 'exif',
+        Writable => 'rational',
+        PrintConv => '$val =~ /^(inf|undef)$/ ? $val : "$val m"',
+        PrintConvInv => '$val=~s/\s*m$//;$val',
+    },
+);
+my %sCVTermDetails = (
+    STRUCT_NAME => 'CVTermDetails',
+    NAMESPACE   => 'Iptc4xmpExt',
+    CvTermId    => { },
+    CvTermName  => { Writable => 'lang-alt' },
+    CvId        => { },
+    CvTermRefinedAbout => { },
+);
+
+# IPTC video extensions
+my %sPublicationEvent = (
+    STRUCT_NAME => 'PublicationEvent',
+    NAMESPACE   => 'Iptc4xmpExt',
+    Date        => { Groups => { 2 => 'Time' }, %dateTimeInfo },
+    Name        => { },
+    Identifier  => { },
+);
+my %sEntity = (
+    STRUCT_NAME => 'Entity',
+    NAMESPACE   => 'Iptc4xmpExt',
+    Identifier  => { List => 'Bag', Namespace => 'xmp' },
+    Name        => { Writable => 'lang-alt' },
+);
+my %sEntityWithRole = (
+    STRUCT_NAME => 'EntityWithRole',
+    NAMESPACE   => 'Iptc4xmpExt',
+    Identifier  => { List => 'Bag', Namespace => 'xmp' },
+    Name        => { Writable => 'lang-alt' },
+    Role        => { List => 'Bag' },
+);
+my %sFrameSize = (
+    STRUCT_NAME => 'FrameSize',
+    NAMESPACE   => 'Iptc4xmpExt',
+    WidthPixels  => { Writable => 'integer' },
+    HeightPixels => { Writable => 'integer' },
+);
+my %sRating = (
+    STRUCT_NAME => 'Rating',
+    NAMESPACE   => 'Iptc4xmpExt',
+    RatingValue         => { FlatName => 'Value' },
+    RatingSourceLink    => { FlatName => 'SourceLink' },
+    RatingScaleMinValue => { FlatName => 'ScaleMinValue' },
+    RatingScaleMaxValue => { FlatName => 'ScaleMaxValue' },
+    RatingValueLogoLink => { FlatName => 'ValueLogoLink' },
+    RatingRegion => {
+        FlatName => 'RatingRegion',
+        Struct => \%sLocationDetails,
+        List => 'Bag',
+    },
+);
+my %sEpisode = (
+    STRUCT_NAME => 'EpisodeOrSeason',
+    NAMESPACE   => 'Iptc4xmpExt',
+    Name        => { },
+    Number      => { },
+    Identifier  => { },
+);
+my %sSeries = (
+    STRUCT_NAME => 'Series',
+    NAMESPACE   => 'Iptc4xmpExt',
+    Name        => { },
+    Identifier  => { },
+);
+my %sTemporalCoverage = (
+    STRUCT_NAME => 'TemporalCoverage',
+    NAMESPACE   => 'Iptc4xmpExt',
+    tempCoverageFrom => { FlatName => 'From', %dateTimeInfo, Groups => { 2 => 'Time' } },
+    tempCoverageTo   => { FlatName => 'To',   %dateTimeInfo, Groups => { 2 => 'Time' } },
+);
+my %sQualifiedLink = (
+    STRUCT_NAME => 'QualifiedLink',
+    NAMESPACE   => 'Iptc4xmpExt',
+    Link        => { },
+    LinkQualifier => { },
+);
+my %sTextRegion = (
+    STRUCT_NAME => 'TextRegion',
+    NAMESPACE   => 'Iptc4xmpExt',
+    RegionText  => { },
+    Region      => { Struct => \%Image::ExifTool::XMP::sArea },
+);
+my %sLinkedImage = (
+    STRUCT_NAME => 'LinkedImage',
+    NAMESPACE   => 'Iptc4xmpExt',
+    Link        => { },
+    LinkQualifier => { List => 'Bag' },
+    ImageRole   => { },
+   'format'     => { Namespace => 'dc' },
+    WidthPixels => { Writable => 'integer' },
+    HeightPixels=> { Writable => 'integer' },
+    UsedVideoFrame => { Struct => \%sTimecode },
+);
+
+# IPTC Extension namespace properties (Iptc4xmpExt) (ref 4)
+%Image::ExifTool::XMP::iptcExt = (
+    %xmpTableDefaults,
+    GROUPS => { 1 => 'XMP-iptcExt', 2 => 'Author' },
+    NAMESPACE   => 'Iptc4xmpExt',
+    TABLE_DESC => 'XMP IPTC Extension',
+    NOTES => q{
+        IPTC Extension namespace tags.  The actual namespace prefix is
+        "Iptc4xmpExt", but ExifTool shortens this for the family 1 group name. (see
+        L<http://www.iptc.org/IPTC4XMP/>)
+    },
+    AboutCvTerm => {
+        Struct => \%sCVTermDetails,
+        List => 'Bag',
+    },
+    AboutCvTermCvId                 => { Flat => 1, Name => 'AboutCvTermCvId' },
+    AboutCvTermCvTermId             => { Flat => 1, Name => 'AboutCvTermId' },
+    AboutCvTermCvTermName           => { Flat => 1, Name => 'AboutCvTermName' },
+    AboutCvTermCvTermRefinedAbout   => { Flat => 1, Name => 'AboutCvTermRefinedAbout' },
+    AddlModelInfo   => { Name => 'AdditionalModelInformation' },
+    ArtworkOrObject => {
+        Struct => {
+            STRUCT_NAME => 'ArtworkOrObjectDetails',
+            NAMESPACE   => 'Iptc4xmpExt',
+            AOCopyrightNotice => { },
+            AOCreator    => { List => 'Seq' },
+            AODateCreated=> { Groups => { 2 => 'Time' }, %dateTimeInfo },
+            AOSource     => { },
+            AOSourceInvNo=> { },
+            AOTitle      => { Writable => 'lang-alt' },
+            AOCurrentCopyrightOwnerName => { },
+            AOCurrentCopyrightOwnerId   => { },
+            AOCurrentLicensorName       => { },
+            AOCurrentLicensorId         => { },
+            AOCreatorId                 => { List => 'Seq' },
+            AOCircaDateCreated          => { Groups => { 2 => 'Time' }, Protected => 1 },
+            AOStylePeriod               => { List => 'Bag' },
+            AOSourceInvURL              => { },
+            AOContentDescription        => { Writable => 'lang-alt' },
+            AOContributionDescription   => { Writable => 'lang-alt' },
+            AOPhysicalDescription       => { Writable => 'lang-alt' },
+        },
+        List => 'Bag',
+    },
+    ArtworkOrObjectAOCopyrightNotice           => { Flat => 1, Name => 'ArtworkCopyrightNotice' },
+    ArtworkOrObjectAOCreator                   => { Flat => 1, Name => 'ArtworkCreator' },
+    ArtworkOrObjectAODateCreated               => { Flat => 1, Name => 'ArtworkDateCreated' },
+    ArtworkOrObjectAOSource                    => { Flat => 1, Name => 'ArtworkSource' },
+    ArtworkOrObjectAOSourceInvNo               => { Flat => 1, Name => 'ArtworkSourceInventoryNo' },
+    ArtworkOrObjectAOTitle                     => { Flat => 1, Name => 'ArtworkTitle' },
+    ArtworkOrObjectAOCurrentCopyrightOwnerName => { Flat => 1, Name => 'ArtworkCopyrightOwnerName' },
+    ArtworkOrObjectAOCurrentCopyrightOwnerId   => { Flat => 1, Name => 'ArtworkCopyrightOwnerID' },
+    ArtworkOrObjectAOCurrentLicensorName       => { Flat => 1, Name => 'ArtworkLicensorName' },
+    ArtworkOrObjectAOCurrentLicensorId         => { Flat => 1, Name => 'ArtworkLicensorID' },
+    ArtworkOrObjectAOCreatorId                 => { Flat => 1, Name => 'ArtworkCreatorID' },
+    ArtworkOrObjectAOCircaDateCreated          => { Flat => 1, Name => 'ArtworkCircaDateCreated' },
+    ArtworkOrObjectAOStylePeriod               => { Flat => 1, Name => 'ArtworkStylePeriod' },
+    ArtworkOrObjectAOSourceInvURL              => { Flat => 1, Name => 'ArtworkSourceInvURL' },
+    ArtworkOrObjectAOContentDescription        => { Flat => 1, Name => 'ArtworkContentDescription' },
+    ArtworkOrObjectAOContributionDescription   => { Flat => 1, Name => 'ArtworkContributionDescription' },
+    ArtworkOrObjectAOPhysicalDescription       => { Flat => 1, Name => 'ArtworkPhysicalDescription' },
+    CVterm => {
+        Name => 'ControlledVocabularyTerm',
+        List => 'Bag',
+        Notes => 'deprecated by version 1.2',
+    },
+    DigImageGUID            => { Name => 'DigitalImageGUID' },
+    DigitalSourcefileType   => {
+        Name => 'DigitalSourceFileType',
+        Notes => 'now deprecated -- replaced by DigitalSourceType',
+    },
+    DigitalSourceType       => { Name => 'DigitalSourceType' },
+    EmbdEncRightsExpr => {
+        Struct => {
+            STRUCT_NAME => 'EEREDetails',
+            NAMESPACE   => 'Iptc4xmpExt',
+            EncRightsExpr       => { },
+            RightsExprEncType   => { },
+            RightsExprLangId    => { },
+        },
+        List => 'Bag',
+    },
+    EmbdEncRightsExprEncRightsExpr      => { Flat => 1, Name => 'EmbeddedEncodedRightsExpr' },
+    EmbdEncRightsExprRightsExprEncType  => { Flat => 1, Name => 'EmbeddedEncodedRightsExprType' },
+    EmbdEncRightsExprRightsExprLangId   => { Flat => 1, Name => 'EmbeddedEncodedRightsExprLangID' },
+    Event       => { Writable => 'lang-alt' },
+    IptcLastEdited => {
+        Name => 'IPTCLastEdited',
+        Groups => { 2 => 'Time' },
+        %dateTimeInfo,
+    },
+    LinkedEncRightsExpr => {
+        Struct => {
+            STRUCT_NAME => 'LEREDetails',
+            NAMESPACE   => 'Iptc4xmpExt',
+            LinkedRightsExpr    => { },
+            RightsExprEncType   => { },
+            RightsExprLangId    => { },
+        },
+        List => 'Bag',
+    },
+    LinkedEncRightsExprLinkedRightsExpr  => { Flat => 1, Name => 'LinkedEncodedRightsExpr' },
+    LinkedEncRightsExprRightsExprEncType => { Flat => 1, Name => 'LinkedEncodedRightsExprType' },
+    LinkedEncRightsExprRightsExprLangId  => { Flat => 1, Name => 'LinkedEncodedRightsExprLangID' },
+    LocationCreated => {
+        Struct => \%sLocationDetails,
+        Groups => { 2 => 'Location' },
+        List => 'Bag',
+    },
+    LocationShown => {
+        Struct => \%sLocationDetails,
+        Groups => { 2 => 'Location' },
+        List => 'Bag',
+    },
+    MaxAvailHeight          => { Writable => 'integer' },
+    MaxAvailWidth           => { Writable => 'integer' },
+    ModelAge                => { List => 'Bag', Writable => 'integer' },
+    OrganisationInImageCode => { List => 'Bag' },
+    OrganisationInImageName => { List => 'Bag' },
+    PersonInImage           => { List => 'Bag' },
+    PersonInImageWDetails => {
+        Struct => {
+            STRUCT_NAME => 'PersonDetails',
+            NAMESPACE   => 'Iptc4xmpExt',
+            PersonId    => { List => 'Bag' },
+            PersonName  => { Writable => 'lang-alt' },
+            PersonCharacteristic => {
+                Struct  => \%sCVTermDetails,
+                List    => 'Bag',
+            },
+            PersonDescription => { Writable => 'lang-alt' },
+        },
+        List => 'Bag',
+    },
+    PersonInImageWDetailsPersonId                               => { Flat => 1, Name => 'PersonInImageId' },
+    PersonInImageWDetailsPersonName                             => { Flat => 1, Name => 'PersonInImageName' },
+    PersonInImageWDetailsPersonCharacteristic                   => { Flat => 1, Name => 'PersonInImageCharacteristic' },
+    PersonInImageWDetailsPersonCharacteristicCvId               => { Flat => 1, Name => 'PersonInImageCvTermCvId' },
+    PersonInImageWDetailsPersonCharacteristicCvTermId           => { Flat => 1, Name => 'PersonInImageCvTermId' },
+    PersonInImageWDetailsPersonCharacteristicCvTermName         => { Flat => 1, Name => 'PersonInImageCvTermName' },
+    PersonInImageWDetailsPersonCharacteristicCvTermRefinedAbout => { Flat => 1, Name => 'PersonInImageCvTermRefinedAbout' },
+    PersonInImageWDetailsPersonDescription                      => { Flat => 1, Name => 'PersonInImageDescription' },
+    ProductInImage => {
+        Struct => {
+            STRUCT_NAME => 'ProductDetails',
+            NAMESPACE   => 'Iptc4xmpExt',
+            ProductName => { Writable => 'lang-alt' },
+            ProductGTIN => { },
+            ProductDescription => { Writable => 'lang-alt' },
+        },
+        List => 'Bag',
+    },
+    ProductInImageProductName        => { Flat => 1, Name => 'ProductInImageName' },
+    ProductInImageProductGTIN        => { Flat => 1, Name => 'ProductInImageGTIN' },
+    ProductInImageProductDescription => { Flat => 1, Name => 'ProductInImageDescription' },
+    RegistryId => {
+        Name => 'RegistryID',
+        Struct => {
+            STRUCT_NAME => 'RegistryEntryDetails',
+            NAMESPACE   => 'Iptc4xmpExt',
+            RegItemId   => { },
+            RegOrgId    => { },
+            RegEntryRole=> { }, # (new in 1.3)
+        },
+        List => 'Bag',
+    },
+    RegistryIdRegItemId => { Flat => 1, Name => 'RegistryItemID' },
+    RegistryIdRegOrgId  => { Flat => 1, Name => 'RegistryOrganisationID' },
+    RegistryIdRegEntryRole => { Flat => 1, Name => 'RegistryEntryRole' },
+
+    # new Extension 1.3 properties
+    Genre           => { Groups => { 2 => 'Image' }, List => 'Bag', Struct => \%sCVTermDetails },
+
+    # new video properties (Oct 2016, ref Michael Steidl)
+    # (see http://www.iptc.org/std/videometadatahub/recommendation/IPTC-VideoMetadataHub-props-Rec_1.0.html)
+    CircaDateCreated=> { Groups => { 2 => 'Time' } },
+    Episode         => { Groups => { 2 => 'Video' }, Struct => \%sEpisode },
+    ExternalMetadataLink => { Groups => { 2 => 'Other' }, List => 'Bag' },
+    FeedIdentifier  => { Groups => { 2 => 'Video' } },
+    PublicationEvent=> { Groups => { 2 => 'Video' }, List => 'Bag', Struct => \%sPublicationEvent },
+    Rating          => {
+        Groups => { 2 => 'Other' },
+        Struct  => \%sRating,
+        List    => 'Bag',
+    },
+    ReleaseReady    => { Groups => { 2 => 'Other' }, Writable => 'boolean' },
+    Season          => { Groups => { 2 => 'Video' }, Struct => \%sEpisode },
+    Series          => { Groups => { 2 => 'Video' }, Struct => \%sSeries },
+    StorylineIdentifier => { Groups => { 2 => 'Video' }, List => 'Bag' },
+    StylePeriod     => { Groups => { 2 => 'Video' } },
+    TemporalCoverage=> { Groups => { 2 => 'Video' }, Struct => \%sTemporalCoverage },
+    WorkflowTag     => { Groups => { 2 => 'Video' }, Struct => \%sCVTermDetails },
+    DataOnScreen    => { Groups => { 2 => 'Video' }, List => 'Bag', Struct => \%sTextRegion },
+    Dopesheet       => { Groups => { 2 => 'Video' }, Writable => 'lang-alt' },
+    DopesheetLink   => { Groups => { 2 => 'Video' }, List => 'Bag', Struct => \%sQualifiedLink },
+    Headline        => { Groups => { 2 => 'Video' }, Writable => 'lang-alt', Avoid => 1 },
+    PersonHeard     => { Groups => { 2 => 'Audio' }, List => 'Bag', Struct => \%sEntity },
+    VideoShotType   => { Groups => { 2 => 'Video' }, List => 'Bag', Struct => \%sEntity },
+    EventExt        => { Groups => { 2 => 'Video' }, List => 'Bag', Struct => \%sEntity, Name => 'ShownEvent' },
+    Transcript      => { Groups => { 2 => 'Video' }, Writable => 'lang-alt' },
+    TranscriptLink  => { Groups => { 2 => 'Video' }, List => 'Bag', Struct => \%sQualifiedLink },
+    VisualColour    => {
+        Name => 'VisualColor',
+        Groups => { 2 => 'Video' },
+        PrintConv => {
+            'bw-monochrome' => 'Monochrome',
+            'colour'        => 'Color',
+        },
+    },
+    Contributor     => { List => 'Bag', Struct => \%sEntityWithRole },
+    CopyrightYear   => { Groups => { 2 => 'Time' },  Writable => 'integer' },
+    Creator         => { List => 'Bag', Struct => \%sEntityWithRole },
+    SupplyChainSource => { Groups => { 2 => 'Other' }, List => 'Bag', Struct => \%sEntity },
+    audioBitRate    => { Groups => { 2 => 'Audio' }, Writable => 'integer', Name => 'AudioBitrate' },
+    audioBitRateMode=> {
+        Name => 'AudioBitrateMode',
+        Groups => { 2 => 'Audio' },
+        PrintConv => {
+            fixed => 'Fixed',
+            variable => 'Variable',
+        },
+    },
+    audioChannelCount       => { Groups => { 2 => 'Audio' }, Writable => 'integer' },
+    videoDisplayAspectRatio => { Groups => { 2 => 'Audio' }, Writable => 'rational' },
+    ContainerFormat         => { Groups => { 2 => 'Video' }, Struct => \%sEntity },
+    StreamReady => {
+        Groups => { 2 => 'Video' },
+        PrintConv => {
+            true => 'True',
+            false => 'False',
+            unknown => 'Unknown',
+        },
+    },
+    videoBitRate     => { Groups => { 2 => 'Video' }, Writable => 'integer', Name => 'VideoBitrate' },
+    videoBitRateMode => {
+        Name => 'VideoBitrateMode',
+        Groups => { 2 => 'Video' },
+        PrintConv => {
+            fixed => 'Fixed',
+            variable => 'Variable',
+        },
+    },
+    videoEncodingProfile => { Groups => { 2 => 'Video' } },
+    videoStreamsCount    => { Groups => { 2 => 'Video' }, Writable => 'integer' },
+    # new IPTC video metadata 1.1 properties
+    # (ref https://www.iptc.org/std/videometadatahub/recommendation/IPTC-VideoMetadataHub-props-Rec_1.1.html)
+    SnapshotLink => { Groups => { 2 => 'Image' }, List => 'Bag', Struct => \%sLinkedImage, Name => 'Snapshot' },
+);
+
 #------------------------------------------------------------------------------
 # PRISM
 #
-# NOTE: The "Avoid" flag is set for all PRISM tags
+# NOTE: The "Avoid" flag is set for all PRISM tags (via tag table AVOID flag)
 
 # my %obsolete = (
 #     Notes => 'obsolete in 2.0',
@@ -330,11 +701,12 @@ my %prismPublicationDate = (
     %xmpTableDefaults,
     GROUPS => { 0 => 'XMP', 1 => 'XMP-prism', 2 => 'Document' },
     NAMESPACE => 'prism',
+    AVOID => 1,
     NOTES => q{
         Publishing Requirements for Industry Standard Metadata 3.0 namespace
         tags.  (see L<http://www.prismstandard.org/>)
     },
-    acedemicField   => { }, # (3.0)
+    academicField   => { }, # (3.0)
     aggregateIssueNumber => { Writable => 'integer' }, # (3.0)
     aggregationType => { List => 'Bag' },
     alternateTitle  => {
@@ -547,6 +919,7 @@ my %prismPublicationDate = (
     %xmpTableDefaults,
     GROUPS => { 0 => 'XMP', 1 => 'XMP-prl', 2 => 'Document' },
     NAMESPACE => 'prl',
+    AVOID => 1,
     NOTES => q{
         PRISM Rights Language 2.1 namespace tags.  These tags have been deprecated
         since the release of the PRISM Usage Rights 3.0. (see
@@ -562,6 +935,7 @@ my %prismPublicationDate = (
     %xmpTableDefaults,
     GROUPS => { 0 => 'XMP', 1 => 'XMP-pur', 2 => 'Document' },
     NAMESPACE => 'pur',
+    AVOID => 1,
     NOTES => q{
         PRISM Usage Rights 3.0 namespace tags.  (see
         L<http://www.prismstandard.org/>)
@@ -593,6 +967,7 @@ my %prismPublicationDate = (
     %xmpTableDefaults,
     GROUPS => { 0 => 'XMP', 1 => 'XMP-pmi', 2 => 'Image' },
     NAMESPACE => 'pmi',
+    AVOID => 1,
     NOTES => q{
         PRISM Metadata for Images 3.0 namespace tags.  (see
         L<http://www.prismstandard.org/>)
@@ -659,6 +1034,7 @@ my %prismPublicationDate = (
     %xmpTableDefaults,
     GROUPS => { 0 => 'XMP', 1 => 'XMP-prm', 2 => 'Document' },
     NAMESPACE => 'prm',
+    AVOID => 1,
     NOTES => q{
         PRISM Recipe Metadata 3.0 namespace tags.  (see
         L<http://www.prismstandard.org/>)
@@ -722,17 +1098,18 @@ my %prismPublicationDate = (
 %Image::ExifTool::XMP::PixelLive = (
     GROUPS => { 1 => 'XMP-PixelLive', 2 => 'Image' },
     NAMESPACE => 'PixelLive',
+    AVOID => 1,
     NOTES => q{
         PixelLive namespace tags.  These tags are not writable becase they are very
         uncommon and I haven't been able to locate a reference which gives the
         namespace URI.
     },
-    AUTHOR    => { Name => 'Author',   Avoid => 1, Groups => { 2 => 'Author' } },
-    COMMENTS  => { Name => 'Comments', Avoid => 1 },
-    COPYRIGHT => { Name => 'Copyright',Avoid => 1, Groups => { 2 => 'Author' } },
-    DATE      => { Name => 'Date',     Avoid => 1, Groups => { 2 => 'Time' } },
-    GENRE     => { Name => 'Genre',    Avoid => 1 },
-    TITLE     => { Name => 'Title',    Avoid => 1 },
+    AUTHOR    => { Name => 'Author',    Groups => { 2 => 'Author' } },
+    COMMENTS  => { Name => 'Comments' },
+    COPYRIGHT => { Name => 'Copyright', Groups => { 2 => 'Author' } },
+    DATE      => { Name => 'Date',      Groups => { 2 => 'Time' } },
+    GENRE     => { Name => 'Genre' },
+    TITLE     => { Name => 'Title' },
 );
 
 # Extensis Portfolio tags (extensis) (ref 11)
@@ -805,6 +1182,8 @@ my %sSubVersion = (
     SubVersions => { Struct => \%sSubVersion, List => 'Bag' },
     SubVersionsVersRef => { Name => 'SubVersionReference', Flat => 1 },
     SubVersionsFileName => { Name => 'SubVersionFileName', Flat => 1 },
+    TimeStamp  => { Avoid => 1, Groups => { 2 => 'Time' }, %dateTimeInfo },
+    AppVersion => { Avoid => 1 },
 );
 
 # ACDSee namespace (acdsee) (ref PH)
@@ -812,6 +1191,7 @@ my %sSubVersion = (
     %xmpTableDefaults,
     GROUPS => { 0 => 'XMP', 1 => 'XMP-acdsee', 2 => 'Image' },
     NAMESPACE => 'acdsee',
+    AVOID => 1,
     NOTES => q{
         ACD Systems ACDSee namespace tags.
 
@@ -821,15 +1201,15 @@ my %sSubVersion = (
         mumble to themselves instead of speaking out for the rest of the world to
         hear.)
     },
-    author     => { Avoid => 1, Groups => { 2 => 'Author' } },
-    caption    => { Avoid => 1 },
-    categories => { Avoid => 1 },
-    collections=> { Avoid => 1 },
-    datetime   => { Name => 'DateTime', Avoid => 1, Groups => { 2 => 'Time' }, %dateTimeInfo },
-    keywords   => { Avoid => 1, List => 'Bag' },
-    notes      => { Avoid => 1 },
-    rating     => { Avoid => 1, Writable => 'real' }, # integer?
-    tagged     => { Avoid => 1, Writable => 'boolean' },
+    author     => { Groups => { 2 => 'Author' } },
+    caption    => { },
+    categories => { },
+    collections=> { },
+    datetime   => { Name => 'DateTime', Groups => { 2 => 'Time' }, %dateTimeInfo },
+    keywords   => { List => 'Bag' },
+    notes      => { },
+    rating     => { Writable => 'real' }, # integer?
+    tagged     => { Writable => 'boolean' },
     rawrppused => { Writable => 'boolean' },
     rpp => {
         Name => 'RPP',
@@ -844,13 +1224,13 @@ my %sSubVersion = (
         Binary => 1,
     },
     # more tags (ref forum6840)
-    FixtureIdentifier   => { Avoid => 1 },
-    EditStatus          => { Avoid => 1 },
-    ReleaseDate         => { Avoid => 1 },
-    ReleaseTime         => { Avoid => 1 },
-    OriginatingProgram  => { Avoid => 1 },
-    ObjectCycle         => { Avoid => 1 },
-    Snapshots           => { Avoid => 1, List => 'Bag', Binary => 1 },
+    FixtureIdentifier   => { },
+    EditStatus          => { },
+    ReleaseDate         => { },
+    ReleaseTime         => { },
+    OriginatingProgram  => { },
+    ObjectCycle         => { },
+    Snapshots           => { List => 'Bag', Binary => 1 },
 );
 
 # Picture Licensing Universal System namespace properties (xmpPLUS)
@@ -858,13 +1238,14 @@ my %sSubVersion = (
     %xmpTableDefaults,
     GROUPS => { 1 => 'XMP-xmpPLUS', 2 => 'Author' },
     NAMESPACE => 'xmpPLUS',
+    AVOID => 1,
     NOTES => q{
         XMP Picture Licensing Universal System (PLUS) tags as written by some older
         Adobe applications.  See L<PLUS XMP Tags|Image::ExifTool::TagNames/PLUS XMP Tags>
         for the current PLUS tags.
     },
-    CreditLineReq   => { Writable => 'boolean', Avoid => 1 },
-    ReuseAllowed    => { Writable => 'boolean', Avoid => 1 },
+    CreditLineReq   => { Writable => 'boolean' },
+    ReuseAllowed    => { Writable => 'boolean' },
 );
 
 # Creative Commons namespace properties (cc) (ref 5)
@@ -981,14 +1362,15 @@ my %sSubVersion = (
     %xmpTableDefaults,
     GROUPS => { 1 => 'XMP-expressionmedia', 2 => 'Image' },
     NAMESPACE => 'expressionmedia',
+    AVOID => 1,
     NOTES => q{
         Microsoft Expression Media namespace tags.  These tags are avoided when
         writing due to name conflicts with tags in other schemas.
     },
-    Event       => { Avoid => 1 },
-    Status      => { Avoid => 1 },
-    People      => { Avoid => 1, List => 'Bag' },
-    CatalogSets => { Avoid => 1, List => 'Bag' },
+    Event       => { },
+    Status      => { },
+    People      => { List => 'Bag' },
+    CatalogSets => { List => 'Bag' },
 );
 
 # DigiKam namespace tags (ref PH)
@@ -1065,6 +1447,11 @@ my %sSubVersion = (
     Curve4y    => { Writable => 'real' },
     Shadows    => { Writable => 'real', Avoid => 1 },
     Highlights => { Writable => 'real', Avoid => 1 },
+    # the following from StarGeek
+    FaceBalanceOrigI    => { Writable => 'real' },
+    FaceBalanceOrigQ    => { Writable => 'real' },
+    FaceBalanceStrength => { Writable => 'real' },
+    FaceBalanceWarmth   => { Writable => 'real' },
 );
 
 # Adobe creatorAtom properties (ref PH)
@@ -1136,6 +1523,32 @@ my %sSubVersion = (
     ConfidenceLevel => { Writable => 'integer' },
 );
 
+# Google audio namespace
+%Image::ExifTool::XMP::GAudio = (
+    %xmpTableDefaults,
+    GROUPS => { 1 => 'XMP-GAudio', 2 => 'Audio' },
+    NAMESPACE => 'GAudio',
+    Data => {
+        Name => 'AudioData',
+        ValueConv => 'Image::ExifTool::XMP::DecodeBase64($val)',
+        ValueConvInv => 'Image::ExifTool::XMP::EncodeBase64($val)',
+    },
+    Mime => { Name => 'AudioMimeType' },
+);
+
+# Google image namespace
+%Image::ExifTool::XMP::GImage = (
+    %xmpTableDefaults,
+    GROUPS => { 1 => 'XMP-GImage', 2 => 'Image' },
+    NAMESPACE => 'GImage',
+    Data => {
+        Name => 'ImageData',
+        ValueConv => 'Image::ExifTool::XMP::DecodeBase64($val)',
+        ValueConvInv => 'Image::ExifTool::XMP::EncodeBase64($val)',
+    },
+    Mime => { Name => 'ImageMimeType' },
+);
+
 # Google panorama namespace properties
 # (ref http://u88.n24.queensu.ca/exiftool/forum/index.php/topic,4569.0.html)
 %Image::ExifTool::XMP::GPano = (
@@ -1175,6 +1588,101 @@ my %sSubVersion = (
     LargestValidInteriorRectHeight  => { Writable => 'real' },
 );
 
+# Google Spherical Images namespace (ref https://github.com/google/spatial-media/blob/master/docs/spherical-video-rfc.md)
+%Image::ExifTool::XMP::GSpherical = (
+    %xmpTableDefaults,
+    GROUPS => { 1 => 'XMP-GSpherical', 2 => 'Image' },
+    NAMESPACE => 'GSpherical',
+    AVOID => 1,
+    NOTES => q{
+        Not actually XMP.  These RDF/XML tags are used in Google spherical MP4
+        videos.  See
+        L<https://github.com/google/spatial-media/blob/master/docs/spherical-video-rfc.md>
+        for the specification.
+    },
+    # (avoid due to conflicts with XMP-GPano tags)
+    Spherical                   => { Writable => 'boolean' },
+    Stitched                    => { Writable => 'boolean' },
+    StitchingSoftware           => { },
+    ProjectionType              => { },
+    StereoMode                  => { },
+    SourceCount                 => { Writable => 'integer' },
+    InitialViewHeadingDegrees   => { Writable => 'real' },
+    InitialViewPitchDegrees     => { Writable => 'real' },
+    InitialViewRollDegrees      => { Writable => 'real' },
+    Timestamp                   => {
+        Name => 'TimeStamp',
+        Groups => { 2 => 'Time' },
+        Writable => 'integer',
+        Shift => 'Time',
+        ValueConv => 'ConvertUnixTime($val)', #(NC)
+        ValueConvInv => 'GetUnixTime($val)',
+        PrintConv => '$self->ConvertDateTime($val)',
+        PrintConvInv => '$self->InverseDateTime($val)',
+    },
+    FullPanoWidthPixels         => { Writable => 'integer' },
+    FullPanoHeightPixels        => { Writable => 'integer' },
+    CroppedAreaImageWidthPixels => { Writable => 'integer' },
+    CroppedAreaImageHeightPixels=> { Writable => 'integer' },
+    CroppedAreaLeftPixels       => { Writable => 'integer' },
+    CroppedAreaTopPixels        => { Writable => 'integer' },
+);
+
+# Google depthmap information (ref https://developers.google.com/depthmap-metadata/reference)
+%Image::ExifTool::XMP::GDepth = (
+    GROUPS      => { 0 => 'XMP', 1 => 'XMP-GDepth', 2 => 'Image' },
+    NAMESPACE   => { 'GDepth' => 'http://ns.google.com/photos/1.0/depthmap/' },
+    AVOID       => 1, # (too potential tag name conflicts)
+    NOTES       => q{
+        Google depthmap information. See
+        L<https://developers.google.com/depthmap-metadata/> for the specification.
+    },
+    WRITABLE    => 'string', # (default to string-type tags)
+    PRIORITY    => 0,
+    Format => {
+        PrintConv => {
+            RangeInverse => 'RangeInverse',
+            RangeLinear  => 'RangeLinear',
+        },
+    },
+    Near        => { Writable => 'real' },
+    Far         => { Writable => 'real' },
+    Mime        => { },
+    Data => {
+        ValueConv => 'Image::ExifTool::XMP::DecodeBase64($val)',
+        ValueConvInv => 'Image::ExifTool::XMP::EncodeBase64($val)',
+    },
+    Units       => { },
+    MeasureType => {
+        PrintConv => {
+            OpticalAxis => 'OpticalAxis',
+            OpticalRay  => 'OpticalRay',
+        },
+    },
+    ConfidenceMime  => { },
+    Confidence => {
+        ValueConv => 'Image::ExifTool::XMP::DecodeBase64($val)',
+        ValueConvInv => 'Image::ExifTool::XMP::EncodeBase64($val)',
+    },
+    Manufacturer=> { },
+    Model       => { },
+    Software    => { },
+    ImageWidth  => { Writable => 'real' },
+    ImageHeight => { Writable => 'real' },
+);
+
+# Google focus namespace
+%Image::ExifTool::XMP::GFocus = (
+    %xmpTableDefaults,
+    GROUPS => { 1 => 'XMP-GFocus', 2 => 'Image' },
+    NAMESPACE => 'GFocus',
+    NOTES => 'Focus information found in Google depthmap images.',
+    BlurAtInfinity  => { Writable => 'real' },
+    FocalDistance   => { Writable => 'real' },
+    FocalPointX     => { Writable => 'real' },
+    FocalPointY     => { Writable => 'real' },
+);
+
 # Getty Images namespace (ref PH)
 %Image::ExifTool::XMP::GettyImages = (
     %xmpTableDefaults,
@@ -1185,44 +1693,27 @@ my %sSubVersion = (
         prefix recorded in the file, but ExifTool shortens this for the family 1
         group name.
     },
-    Personality => { },
-    OriginalFilename => { Name => 'OriginalFileName' },
-    ParentMEID => { },
-);
-
-# Google Spherical Images namespace (ref https://github.com/google/spatial-media/blob/master/docs/spherical-video-rfc.md)
-%Image::ExifTool::XMP::GSpherical = (
-    %xmpTableDefaults,
-    WRITABLE => 0,
-    GROUPS => { 1 => 'XMP-GSpherical', 2 => 'Image' },
-    NAMESPACE => 'GSpherical',
-    NOTES => q{
-        Not actually XMP.  These RDF/XML tags are used in Google spherical MP4
-        videos.  See
-        L<https://github.com/google/spatial-media/blob/master/docs/spherical-video-rfc.md>
-        for the specification.
-    },
-    Spherical                   => { },
-    Stitched                    => { },
-    StitchingSoftware           => { },
-    ProjectionType              => { },
-    StereoMode                  => { },
-    SourceCount                 => { },
-    InitialViewHeadingDegrees   => { },
-    InitialViewPitchDegrees     => { },
-    InitialViewRollDegrees      => { },
-    Timestamp                   => {
-        Name => 'TimeStamp',
-        Groups => { 2 => 'Time' },
-        ValueConv => 'ConvertUnixTime($val)', #(NC)
-        PrintConv => '$self->ConvertDateTime($val)',
-    },
-    FullPanoWidthPixels         => { },
-    FullPanoHeightPixels        => { },
-    CroppedAreaImageWidthPixels => { },
-    CroppedAreaImageHeightPixels=> { },
-    CroppedAreaLeftPixels       => { },
-    CroppedAreaTopPixels        => { },
+    Personality         => { },
+    OriginalFilename    => { Name => 'OriginalFileName' },
+    ParentMEID          => { },
+    # the following from StarGeek
+    AssetID             => { },
+    CallForImage        => { },
+    CameraFilename      => { },
+    CameraMakeModel     => { Avoid => 1 },
+    Composition         => { },
+    CameraSerialNumber  => { Avoid => 1 },
+    ExclusiveCoverage   => { },
+    GIFTFtpPriority     => { },
+    ImageRank           => { },
+    MediaEventIdDate    => { },
+    OriginalCreateDateTime => { %dateTimeInfo, Groups => { 2 => 'Time' }, Avoid => 1 },
+    ParentMediaEventID  => { },
+    PrimaryFTP          => { List => 'Bag' },
+    RoutingDestinations => { List => 'Bag' },
+    RoutingExclusions   => { List => 'Bag' },
+    SecondaryFTP        => { List => 'Bag' },
+    TimeShot            => { },
 );
 
 # SVG namespace properties (ref 9)
@@ -1257,21 +1748,6 @@ my %sSubVersion = (
     NAMESPACE => undef, # variable namespace
 );
 
-# set "Avoid" flag for all PRISM tags
-my ($table, $key);
-foreach $table (
-    \%Image::ExifTool::XMP::prism,
-    \%Image::ExifTool::XMP::prl,
-    \%Image::ExifTool::XMP::pur,
-    \%Image::ExifTool::XMP::pmi,
-    \%Image::ExifTool::XMP::prm)
-{
-    foreach $key (TagTableKeys($table)) {
-        $$table{$key}{Avoid} = 1;
-    }
-}
-
-
 1;  #end
 
 __END__
@@ -1290,7 +1766,7 @@ This file contains definitions for less common XMP namespaces.
 
 =head1 AUTHOR
 
-Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2018, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -1305,6 +1781,8 @@ under the same terms as Perl itself.
 
 =item L<http://www.portfoliofaq.com/pfaq/v7mappings.htm>
 
+=item L<http://www.iptc.org/IPTC4XMP/>
+
 =item L<http://creativecommons.org/technology/xmp>
 
 =item L<http://www.optimasc.com/products/fileid/xmp-extensions.pdf>
